pub enum PrCommentCmd {
Create {
number: i64,
body: CommentArgs,
path: Option<String>,
position: Option<i64>,
commit_id: Option<String>,
},
List {
number: i64,
comment_type: Option<String>,
limit: LimitArgs,
},
Edit {
target: i64,
last: bool,
body: Option<String>,
},
Delete {
target: i64,
last: bool,
yes: bool,
},
}Variants
Create
Create a comment on a pull request.
Fields

body: CommentArgsList
List comments on a pull request.
Fields
Edit
Edit a comment by id, or the current user’s latest on a PR via --last.
Fields
Delete
Delete a comment by id, or the current user’s latest on a PR via --last.